---
title: Urubu 
layout: home
content:
    - start 
    - install
    - manual 
    - status
    - sites
    - about
---
A micro CMS for static websites, with a focus on good
navigation practices.

Built with Python and established technologies
for authoring and templating.

